@@ -1,5 +1,5 @@
 # Author: Mainak Jas <mainak.jas@telecom-paristech.fr>
-# License: BSD (3-clause)
+# License: BSD-3-Clause
 
 import numpy as np
 import pytest
@@ -18,7 +18,7 @@ data_path = sample.data_path()
 raw_fname = data_path + '/MEG/sample/sample_audvis_filt-0-40_raw.fif'
 raw = io.read_raw_fif(raw_fname, preload=False)
 raw.crop(0, 15)
-raw.info['projs'] = list()
+raw.del_proj()
 
 
 def test_viz():
@@ -46,3 +46,7 @@ def test_viz():
     pytest.raises(ValueError, reject_log.plot_epochs, epochs[:2])
     pytest.raises(ValueError, reject_log.plot, 'down')
     plt.close('all')
+
+    fig_in, ax = plt.subplots()
+    fig_out = reject_log.plot(ax=ax)
+    assert fig_in == fig_out
